% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lsolve_BICG.R
\name{lsolve.bicg}
\alias{lsolve.bicg}
\title{Biconjugate Gradient method}
\usage{
lsolve.bicg(A, B, xinit = NA, reltol = 1e-05, maxiter = 10000,
  preconditioner = diag(ncol(A)), verbose = TRUE)
}
\arguments{
\item{A}{an \code{(m-by-n)} dense or sparse matrix. See also \code{\link[Matrix]{sparseMatrix}}.}

\item{B}{a vector of length \code{m} or an \code{(m-by-k)} matrix (dense or sparse) for solving \code{k} systems simultaneously.}

\item{xinit}{a length-\code{n} vector for initial starting point. \code{NA} to start from a random initial point near 0.}

\item{reltol}{tolerance level for stopping iterations.}

\item{maxiter}{maximum number of iterations allowed.}

\item{preconditioner}{an \code{(n-by-n)} preconditioning matrix; default is an identity matrix.}

\item{verbose}{a logical; \code{TRUE} to show progress of computation.}
}
\value{
a named list containing \describe{
\item{x}{a solution of length \code{n}.}
\item{iter}{the number of iterations required.}
\item{errors}{a vector of errors for stopping criterion.}
}
}
\description{
Biconjugate Gradient(BiCG) method is a modification of Conjugate Gradient for nonsymmetric systems using
evaluations with respect to \eqn{A^T} as well as \eqn{A} in matrix-vector multiplications.
For an overdetermined system where \code{nrow(A)>ncol(A)},
it is automatically transformed to the normal equation. Underdetermined system -
\code{nrow(A)<ncol(A)} - is not supported. Preconditioning matrix \eqn{M}, in theory, should be symmetric and positive definite
with fast computability for inverse, though it is not limited until the solver level.
}
\examples{
## Overdetermined System
A = matrix(rnorm(10*5),nrow=10)
x = rnorm(5)
b = A\%*\%x

out1 = lsolve.cg(A,b)
out2 = lsolve.bicg(A,b)
matout = cbind(matrix(x),out1$x, out2$x);
colnames(matout) = c("true x","CG result", "BiCG result")
print(matout)
}
\references{
Fletcher, R. (1976) \emph{Conjugate gradient methods for indefinite systems}, Numerical Analysis, Vol.506:73-89.

Voevodin, V. (1983) \emph{The problem of non-self-adjoint generalization of the
conjugate gradient method is closed}, U.S.S.R. Comput. Maths. and Math. Physics., Vol.23:143-144.
}
